!function(e){const t=e.ug=e.ug||{};t.dictionary=Object.assign(t.dictionary||{},{"%0 of %1":"%0 / %1","Align cell text to the bottom":"","Align cell text to the center":"","Align cell text to the left":"","Align cell text to the middle":"","Align cell text to the right":"","Align cell text to the top":"","Align center":"ئوتتۇرىغا توغرىلاش","Align left":"سولغا توغرىلاش","Align right":"ئوڭغا توغرىلاش","Align table to the left":"","Align table to the right":"",Alignment:"",Aquamarine:"",Background:"",Big:"چوڭ",Black:"","Block quote":"نەقىل",Blue:"",Bold:"توم",Border:"","Break text":"","Bulleted List":"بەلگە تىزىملىك","Bulleted list styles toolbar":"",Cancel:"ۋاز كەچ","Cannot upload file:":"يۈكلەشكە بولمايدىغان ھۆججەت:","Caption for image: %0":"","Caption for the image":"","Cell properties":"","Center table":"","Centered image":"ئوتتۇردىكى رەسىم","Change image text alternative":"رەسىملىك تېكىست تاللىغۇچنى ئۆزگەرتىش","Choose heading":"ماۋزۇ تاللاش",Circle:"",Code:"كود",Color:"","Color picker":"",Column:"",Dashed:"",Decimal:"","Decimal with leading zero":"",Default:"سۈكۈتتىكى","Delete column":"","Delete row":"","Dim grey":"",Dimensions:"",Disc:"","Document colors":"",Dotted:"",Double:"",Downloadable:"","Dropdown toolbar":"","Edit block":"","Edit link":"","Editor block content toolbar":"","Editor contextual toolbar":"","Editor editing area: %0":"","Editor toolbar":"","Enter image caption":"رەسىمنىڭ تېمىسىنى كىرگۈزۈڭ","Enter table caption":"","Font Background Color":"خەت تەگلىك رەڭگى","Font Color":"خەت رەڭگى","Font Family":"خەت نۇسخىسى","Font Size":"خەت چوڭلۇقى","Full size image":"ئەسلى چوڭلۇقتىكى رەسىم",Green:"",Grey:"",Groove:"","Header column":"","Header row":"",Heading:"ماۋزۇ","Heading 1":"ماۋزۇ 1","Heading 2":"ماۋزۇ 2","Heading 3":"ماۋزۇ 3","Heading 4":"ماۋزۇ 4","Heading 5":"ماۋزۇ 5","Heading 6":"ماۋزۇ 6",Height:"","Horizontal text alignment toolbar":"",Huge:"زور","Image resize list":"","Image toolbar":"","image widget":"رەسىمچىك","In line":"",Insert:"","Insert code block":"كود بۆلىكى قىستۇر","Insert column left":"","Insert column right":"","Insert image":"رەسىم قىستۇرۇش","Insert image via URL":"","Insert row above":"","Insert row below":"","Insert table":"جەدۋەل قىستۇر",Inset:"",Italic:"يانتۇ",Justify:"ئوڭ سولدىن توغرىلا","Justify cell text":"","Left aligned image":"سولغا توغۇرلانغان رەسىم","Light blue":"","Light green":"","Light grey":"",Link:"ئۇلانما","Link URL":"ئۇلاش ئادىرسى","List properties":"","Lower-latin":"","Lower–roman":"","Merge cell down":"","Merge cell left":"","Merge cell right":"","Merge cell up":"","Merge cells":"",Next:"",None:"","Numbered List":"نومۇرلۇق تىزىملىك","Numbered list styles toolbar":"","Open in a new tab":"","Open link in new tab":"",Orange:"",Original:"",Outset:"",Padding:"",Paragraph:"ئابزاس","Plain text":"ساپ تېكىست",Previous:"",Purple:"",Red:"",Redo:"تەكرارلاش","Remove color":"رەڭنى چىقىرىۋەت","Resize image":"","Resize image to %0":"","Resize image to the original size":"","Restore default":"كۆڭۈلدىكىگە قايتۇر","Reversed order":"","Rich Text Editor":"تېكىست تەھرىرلىگۈچ",Ridge:"","Right aligned image":"ئوڭغا توغۇرلانغان رەسىم",Row:"",Save:"ساقلا","Select column":"","Select row":"","Show more items":"تېخىمۇ كۆپ تۈرنى كۆرسەت","Side image":"يان رەسىم",Small:"كىچىك",Solid:"","Split cell horizontally":"","Split cell vertically":"",Square:"","Start at":"","Start index must be greater than 0.":"",Strikethrough:"ئۆچۈرۈش سىزىقى",Style:"",Subscript:"ئاستبەلگە",Superscript:"ئۈستبەلگە","Table alignment toolbar":"","Table cell text alignment":"","Table properties":"","Table toolbar":"","Text alignment":"تېكىست توغرىلاش","Text alignment toolbar":"تېكىست توغرىلاش قورالبالدىقى","Text alternative":"تېكىست ئاملاشتۇرۇش",'The color is invalid. Try "#FF0000" or "rgb(255,0,0)" or "red".':"",'The value is invalid. Try "10px" or "2em" or simply "2".':"","This link has no URL":"",Tiny:"ئەڭ كىچىك","To-do List":"","Toggle caption off":"","Toggle caption on":"","Toggle the circle list style":"","Toggle the decimal list style":"","Toggle the decimal with leading zero list style":"","Toggle the disc list style":"","Toggle the lower–latin list style":"","Toggle the lower–roman list style":"","Toggle the square list style":"","Toggle the upper–latin list style":"","Toggle the upper–roman list style":"",Turquoise:"",Underline:"ئاستى سىزىق",Undo:"يېنىۋېلىش",Unlink:"ئۇلانمىنى ئۈزۈش",Update:"","Update image URL":"","Upload failed":"چىقىرىش مەغلۇپ بولدى","Upper-latin":"","Upper-roman":"","Vertical text alignment toolbar":"",White:"",Width:"","Wrap text":"",Yellow:""}),t.getPluralForm=function(e){return 1!=e}}(window.CKEDITOR_TRANSLATIONS||(window.CKEDITOR_TRANSLATIONS={}));