<textarea  name="{{ widget.name }}"{% include "django/forms/widgets/attrs.html" %}>
{% if widget.value %}{{ widget.value }}{% endif %}</textarea>
<div class="word-count" id="word-count-{{script_id}}"></div>
{% if errors %}
{{ errors }}
{% endif %}
<input type="hidden" id="ck-editor-5-upload-url-{{script_id}}" data-upload-url="{{upload_url}}" data-csrf_cookie_name="{{ csrf_cookie_name }}">

{{ config|json_script:script_id}}
